==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt-BR" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Ferramentas de edição de plot</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Configurar os eixos</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Configurar os parâmetros dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Mostrar/ocultar grade</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Mostrar/ocultar grade no plot selecionado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Rotular</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Colocar títulos e rótulos nos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Mostrar/ocultar legenda</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Mostrar/ocultar legenda no plot selecionado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Colocar posições e escalas</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Colocar rótulos e legenda de posições e escalas</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Salvar o plot</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Salvar a imagem como um arquivo de impressão</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Configurar séries</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurar estilos de desenho e rotulagem</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Configurar os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Aplicar a todos os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Dimensões</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>Posição do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Posição do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Escalas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Índice dos eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Adicionar novos eixos ao plot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Remover os eixos selecionados</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Marcar para aplicar as transformações a todos os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Limite esquerdo dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Limite direito dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Limite inferior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Limite superior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Offset para fora do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Offset para fora do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>Seleção automática de escala de eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Seleção automática de escala de eixo y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib não encontrado, o módulo plot não pode ser carregado</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib não encontrado, o módulo plot será desativado</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Um documento plot deve ser selecionado para salvá-lo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Eixos 0 não podem ser excluídos</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>A grade deve ser enquadrada no topo do documento a ser impresso</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>O cabeçalho deve ser enquadrado no topo do documento a ser impresso</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Rotular</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>rótulo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>rótulo Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Índice dos eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Título (associado aos eixos ativos)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Tamanho de fonte do título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>Título do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>Tamanho de fonte do título de eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Título do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Tamanho de fonte do título de eixo y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Colocar posições e escalas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>Posição</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Tamanho</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Lista de itens modificáveis</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Posição do item x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Posição do item y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Tamanho do item</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Salvar a figura</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Polegadas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Pontos por polegada</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Caminho de arquivo de imagem de saída</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Mostrar uma caixa de diálogo de seleção de arquivo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Tamanho x da imagem</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Tamanho y da imagem</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Pontos por polegadas, com tamanho irão definir a resolução de imagem de saída</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Sem rótulo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Remover a serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Estilo de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Configurar séries</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Lista de séries disponíveis</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Título de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Estilo de marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Espessura de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Tamanho do marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Cor de linha e marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Remove esta serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Se for marcado, esta serie não será considerada para fazer a legenda</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Plot/resources/translations/Plot_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="pt-BR" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="46"/>
      <source>Plot edition tools</source>
      <translation>Ferramentas de edição de plot</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="49"/>
      <source>Plot</source>
      <translation>Plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure axes</source>
      <translation>Configurar os eixos</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="68"/>
      <source>Configure the axes parameters</source>
      <translation>Configurar os parâmetros dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="112"/>
      <source>Show/Hide grid</source>
      <translation>Mostrar/ocultar grade</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="115"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Mostrar/ocultar grade no plot selecionado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="155"/>
      <source>Set labels</source>
      <translation>Rotular</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="158"/>
      <source>Set title and axes labels</source>
      <translation>Colocar títulos e rótulos nos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="138"/>
      <source>Show/Hide legend</source>
      <translation>Mostrar/ocultar legenda</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="141"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Mostrar/ocultar legenda no plot selecionado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="172"/>
      <source>Set positions and sizes</source>
      <translation>Colocar posições e escalas</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="175"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Colocar rótulos e legenda de posições e escalas</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save plot</source>
      <translation>Salvar o plot</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="51"/>
      <source>Save the plot as an image file</source>
      <translation>Salvar a imagem como um arquivo de impressão</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series</source>
      <translation>Configurar séries</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="87"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurar estilos de desenho e rotulagem</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Configure axes</source>
      <translation>Configurar os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Active axes</source>
      <translation>Eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="216"/>
      <source>Apply to all axes</source>
      <translation>Aplicar a todos os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Dimensions</source>
      <translation>Dimensões</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="224"/>
      <source>X axis position</source>
      <translation>Posição do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>Y axis position</source>
      <translation>Posição do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="204"/>
      <source>Scales</source>
      <translation>Escalas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="232"/>
      <source>Index of the active axes</source>
      <translation>Índice dos eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="237"/>
      <source>Add new axes to the plot</source>
      <translation>Adicionar novos eixos ao plot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="242"/>
      <source>Remove selected axes</source>
      <translation>Remover os eixos selecionados</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="247"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Marcar para aplicar as transformações a todos os eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="252"/>
      <source>Left bound of axes</source>
      <translation>Limite esquerdo dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Right bound of axes</source>
      <translation>Limite direito dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="262"/>
      <source>Bottom bound of axes</source>
      <translation>Limite inferior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="267"/>
      <source>Top bound of axes</source>
      <translation>Limite superior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="272"/>
      <source>Outward offset of X axis</source>
      <translation>Offset para fora do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="277"/>
      <source>Outward offset of Y axis</source>
      <translation>Offset para fora do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="282"/>
      <source>X axis scale autoselection</source>
      <translation>Seleção automática de escala de eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Y axis scale autoselection</source>
      <translation>Seleção automática de escala de eixo y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="47"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib não encontrado, o módulo plot não pode ser carregado</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="58"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib não encontrado, o módulo plot será desativado</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="48"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Um documento plot deve ser selecionado para salvá-lo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="346"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Eixos 0 não podem ser excluídos</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="101"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>A grade deve ser enquadrada no topo do documento a ser impresso</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="129"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>O cabeçalho deve ser enquadrado no topo do documento a ser impresso</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Set labels</source>
      <translation>Rotular</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Active axes</source>
      <translation>Eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="146"/>
      <source>Title</source>
      <translation>Título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>X label</source>
      <translation>rótulo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Y label</source>
      <translation>rótulo Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Índice dos eixos ativos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Título (associado aos eixos ativos)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Title font size</source>
      <translation>Tamanho de fonte do título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="173"/>
      <source>X axis title</source>
      <translation>Título do eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>X axis title font size</source>
      <translation>Tamanho de fonte do título de eixo x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="183"/>
      <source>Y axis title</source>
      <translation>Título do eixo y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="188"/>
      <source>Y axis title font size</source>
      <translation>Tamanho de fonte do título de eixo y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="124"/>
      <source>Set positions and sizes</source>
      <translation>Colocar posições e escalas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="129"/>
      <source>Position</source>
      <translation>Posição</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="134"/>
      <source>Size</source>
      <translation>Tamanho</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Posição do item x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Y item position</source>
      <translation>Posição do item y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Item size</source>
      <translation>Tamanho do item</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>List of modifiable items</source>
      <translation>Lista de itens modificáveis</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Save figure</source>
      <translation>Salvar a figura</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="137"/>
      <source>Inches</source>
      <translation>Polegadas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Dots per Inch</source>
      <translation>Pontos por polegada</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="147"/>
      <source>Output image file path</source>
      <translation>Caminho de arquivo de imagem de saída</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Show a file selection dialog</source>
      <translation>Mostrar uma caixa de diálogo de seleção de arquivo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Tamanho x da imagem</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Y image size</source>
      <translation>Tamanho y da imagem</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Pontos por polegadas, com tamanho irão definir a resolução de imagem de saída</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>No label</source>
      <translation>Sem rótulo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="192"/>
      <source>Line style</source>
      <translation>Estilo de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Configure series</source>
      <translation>Configurar séries</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="177"/>
      <source>List of available series</source>
      <translation>Lista de séries disponíveis</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="182"/>
      <source>Line title</source>
      <translation>Título de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="197"/>
      <source>Marker style</source>
      <translation>Estilo de marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Line width</source>
      <translation>Espessura de linha</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="207"/>
      <source>Marker size</source>
      <translation>Tamanho do marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Line and marker color</source>
      <translation>Cor de linha e marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Remove series</source>
      <translation>Remover série</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Se selecionado a serie não será considerada para a legenda</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="217"/>
      <source>Removes this series</source>
      <translation>Remove esta série</translation>
    </message>
  </context>
</TS>
